==> dnastack_client_library-3.1.59-py3-none-any.whl: dnastack/client/constants.py <==
from typing import TypeVar

from dnastack.alpha.client.workbench.storage.client import StorageClient
from dnastack.alpha.client.workbench.workflow.client import AlphaWorkflowClient
from dnastack.client.workbench.ewes.client import EWesClient
from dnastack.client.workbench.workbench_user_service.client import WorkbenchUserClient
from dnastack.client.workbench.workflow.client import WorkflowClient
from dnastack.client.base_client import BaseServiceClient
from dnastack.client.collections.client import CollectionServiceClient
from dnastack.client.data_connect import DataConnectClient
from dnastack.client.drs import DrsClient
from dnastack.client.service_registry.client import ServiceRegistry

# All known client classes
ALL_SERVICE_CLIENT_CLASSES = (
    CollectionServiceClient, DataConnectClient, DrsClient, ServiceRegistry, EWesClient, StorageClient, WorkflowClient,
    AlphaWorkflowClient, WorkbenchUserClient)

# All client classes for data access
DATA_SERVICE_CLIENT_CLASSES = (
    CollectionServiceClient, DataConnectClient, DrsClient, EWesClient, StorageClient, WorkflowClient,
    WorkbenchUserClient)

# Type variable for the service client
SERVICE_CLIENT_CLASS = TypeVar('SERVICE_CLIENT_CLASS',
                               BaseServiceClient,
                               EWesClient,
                               StorageClient,
                               WorkflowClient,
                               AlphaWorkflowClient,
                               WorkbenchUserClient,
                               CollectionServiceClient,
                               DataConnectClient,
                               DrsClient,
                               ServiceRegistry)

==> dnastack_client_library-3.1.65a0-py3-none-any.whl: dnastack/client/constants.py <==
from typing import TypeVar

from dnastack.client.workbench.storage.client import StorageClient
from dnastack.client.workbench.samples.client import SamplesClient
from dnastack.client.workbench.ewes.client import EWesClient
from dnastack.client.workbench.workbench_user_service.client import WorkbenchUserClient
from dnastack.client.workbench.workflow.client import WorkflowClient
from dnastack.client.base_client import BaseServiceClient
from dnastack.client.collections.client import CollectionServiceClient
from dnastack.client.data_connect import DataConnectClient
from dnastack.client.drs import DrsClient
from dnastack.client.service_registry.client import ServiceRegistry

# All known client classes
ALL_SERVICE_CLIENT_CLASSES = (
    CollectionServiceClient, DataConnectClient, DrsClient, ServiceRegistry, EWesClient, StorageClient, SamplesClient,
    WorkflowClient,
    WorkbenchUserClient)

# All client classes for data access
DATA_SERVICE_CLIENT_CLASSES = (
    CollectionServiceClient, DataConnectClient, DrsClient, EWesClient, StorageClient, WorkflowClient,
    WorkbenchUserClient)

# Type variable for the service client
SERVICE_CLIENT_CLASS = TypeVar('SERVICE_CLIENT_CLASS',
                               BaseServiceClient,
                               EWesClient,
                               StorageClient,
                               WorkflowClient,
                               WorkbenchUserClient,
                               CollectionServiceClient,
                               DataConnectClient,
                               DrsClient,
                               SamplesClient,
                               ServiceRegistry)
